library(testthat)
expect_message(library(MortalityLaws))

test_check("MortalityLaws")
